



def time_to_seconds(days = 0, hours = 0, minutes = 0, seconds = 5):
    """
    Converts argument's time to pure seconds
    """
    
    hours = hours + 24*days

    minutes = minutes + 60*hours

    seconds = seconds + 60*minutes

    return seconds






from .logical import TRUE, true, T, FALSE, F, false, NULL
from .little import is_number, is_odd, is_even

from .r_funcs import nrow, ncol, colMeans, rowMeans, colSums, rowSums, apply, lapply, sapply, sample, sample_int

from .useful_funcs import fast_sample, randomTrue



from .other import time_to_seconds






import numpy as np


from .logical import TRUE, FALSE, NULL


def nrow(arr2D):
    """
    returns number of rows
    """
    return arr2D.shape[0]

def ncol(arr2D):
    """
    returns number of columns
    """
    return arr2D.shape[1]



def rowSums(arr2D):
    """
    returns sums for each row
    """
    return np.sum(arr2D, axis = 1)

def colSums(arr2D):
    """
    returns sums for each column
    """    
    return np.sum(arr2D, axis = 0)


def rowMeans(arr2D):
    """
    returns average for each row
    """
    return np.mean(arr2D, axis = 1)

def colMeans(arr2D):
    """
    returns average for each column
    """
    return np.mean(arr2D, axis = 0)



def apply(arr2D, MARGIN, FUN):
    """
    applies function FUN to dimension of arr2D array (for rows if MARGIN == 1 and columns if MARGIN == 2) 
    """

    if MARGIN == 1:
        return np.array([FUN(arr2D[i, :]) for i in range(nrow(arr2D))])
    elif MARGIN == 2:
        return np.array([FUN(arr2D[:, i]) for i in range(ncol(arr2D))])
    else:
        raise Exception(f"MARGIN param must be 1 for rows and 2 for columns, not {MARGIN}")


def lapply(array, func):
    """
    applies function func for each element in array (array/list or something else)
    """
    return list(map(func, array)) # faster than [func(a) for a in array] over 1.5 times

def sapply(array, func):
    """
    like lapply but returns numpy array
    """
    return np.array(lapply(array, func))


def sample(array, size, replace = False, prob = None):
    """
    it is np.random.choice but replace = False by default
    """
    return np.random.choice(array, size, replace = replace, p = prob)


def sample_int(n, size = 'same', replace = FALSE, prob = NULL):
    """
    sample numbers from 0 to n-1
    """
    return np.random.choice(n, n if size == 'same' else size, replace = replace, p = prob)













import random


def randomTrue(prob = 0.5):
    return True if random.random() < prob else False


def fast_sample(objects, probs):
    """
    returns 1 random object from objects with probs probabilities 
    """
    x = random.random()
    cum = 0
    for i, p in enumerate(probs):
        cum += p
        if x < cum:
            return objects[i]
    return objects[-1]







import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name="truefalsepython", 
    version="0.1.5",
    author="Demetry Pascal",
    author_email="qtckpuhdsa@gmail.com",
    maintainer = ['Demetry Pascal'],
    description="PyPI package with some better syntax tools for python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/PasaOpasen/true-false-python",
    keywords=['true', 'false', 'C', 'fun', 'funny', 'shit', 'r', 'tools'],
    packages = setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    install_requires=['numpy']
    
    )





